pub fn with_handle_regex<R>(f: impl FnOnce(&Regex) -> R) -> RExpand description
Runs f with as argument a reference to a compiled HANDLE_REGEX
that is cached thread locally.
pub fn with_handle_regex<R>(f: impl FnOnce(&Regex) -> R) -> RRuns f with as argument a reference to a compiled HANDLE_REGEX
that is cached thread locally.